@import "../../../../css/_mixins.scss";
@import "../../../../css/_theme-vars.scss";
@import "../../css/_skin-vars.scss";

//@mixin instagram--sm() {
@media #{$media_sm} {
	/* Instagram */
	.column-1_1 #sb_instagram .sbi_item {
		min-width:25%;
	}
}